@@ -5,7 +5,6 @@ import time
 from typing import TYPE_CHECKING, Any, List, Optional, Tuple, Union
 
 from django.conf import settings
-from django.contrib.postgres.fields import JSONField
 from django.core.cache import cache
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
@@ -16,6 +15,7 @@ from django.utils.timezone import now as tz_now
 from django.utils.translation import gettext_lazy as _lazy
 from elasticsearch_dsl import Search
 
+from .compat import JSONField
 from .settings import (
     get_client,
     get_model_index_properties,
@@ -491,6 +491,11 @@ class SearchQuery(models.Model):
             "Indicates whether this is an exact match ('eq') or a lower bound ('gte')"
         ),
     )
+    aggregations = JSONField(
+        help_text=_lazy("The raw aggregations returned from the query."),
+        encoder=DjangoJSONEncoder,
+        default=dict,
+    )
     reference = models.CharField(
         max_length=100,
         default="",
@@ -583,11 +588,11 @@ class SearchQuery(models.Model):
 
 def execute_search(
     search: Search,
+    *,
     search_terms: str = "",
     user: Optional[AbstractBaseUser] = None,
     reference: Optional[str] = "",
     save: bool = True,
-    query_type: str = SearchQuery.QueryType.SEARCH,  # type: ignore
 ) -> SearchQuery:
     """
     Create a new SearchQuery instance and execute a search against ES.
@@ -605,30 +610,23 @@ def execute_search(
         save: bool, if True then save the new object immediately, can be
             overridden to False to prevent logging absolutely everything.
             Defaults to True
-        query_type: string, used to determine whether to run a search query or
-            a count query (returns hit count, but no results).
 
     """
     start = time.time()
-    if query_type == SearchQuery.QueryType.SEARCH:
-        response = search.execute()
-        hits = [h.meta.to_dict() for h in response.hits]
-        total_hits = response.hits.total.value
-        total_hits_relation = response.hits.total.relation
-    elif query_type == SearchQuery.QueryType.COUNT:
-        response = total_hits = search.count()
-        total_hits_relation = SearchQuery.TotalHitsRelation.ACCURATE
-        hits = []
-    else:
-        raise ValueError(f"Invalid SearchQuery.query_type value: '{query_type}'")
+    response = search.execute()
+    hits = [h.meta.to_dict() for h in response.hits]
+    total_hits = response.hits.total.value
+    total_hits_relation = response.hits.total.relation
+    aggregations = response.aggregations.to_dict()
     duration = time.time() - start
     search_query = SearchQuery(
         user=user,
         search_terms=search_terms,
         index=", ".join(search._index or ["_all"])[:100],  # field length restriction
         query=search.to_dict(),
-        query_type=query_type,
+        query_type=SearchQuery.QueryType.SEARCH,
         hits=hits,
+        aggregations=aggregations,
         total_hits=total_hits,
         total_hits_relation=total_hits_relation,
         reference=reference or "",
@@ -637,3 +635,50 @@ def execute_search(
     )
     search_query.response = response
     return search_query.save() if save else search_query
+
+
+def execute_count(
+    search: Search,
+    *,
+    search_terms: str = "",
+    user: Optional[AbstractBaseUser] = None,
+    reference: Optional[str] = "",
+    save: bool = True,
+) -> SearchQuery:
+    """
+    Run a "count" against ES and store the results.
+
+    Args:
+        search: elasticsearch.search.Search object, that internally contains
+            the connection and query; this is the query that is executed. All
+            we are doing is logging the input and parsing the output.
+        search_terms: raw end user search terms input - what they typed into the search
+            box.
+        user: Django User object, the person making the query - used for logging
+            purposes. Can be null.
+        reference: string, can be anything you like, used for identification,
+            grouping purposes.
+        save: bool, if True then save the new object immediately, can be
+            overridden to False to prevent logging absolutely everything.
+            Defaults to True
+
+    """
+    start = time.time()
+    response = search.count()
+    duration = time.time() - start
+    search_query = SearchQuery(
+        user=user,
+        search_terms=search_terms,
+        index=", ".join(search._index or ["_all"])[:100],  # field length restriction
+        query=search.to_dict(),
+        query_type=SearchQuery.QueryType.COUNT,
+        hits=[],
+        aggregations={},
+        total_hits=response,
+        total_hits_relation=SearchQuery.TotalHitsRelation.ACCURATE,
+        reference=reference or "",
+        executed_at=tz_now(),
+        duration=duration,
+    )
+    search_query.response = response
+    return search_query.save() if save else search_query
